@@ -13,7 +13,7 @@ class XBlockNotFoundError(Exception):
     def __init__(self, usage_id):
         # Exception is an old-style class, so can't use super
         Exception.__init__(self)
-        self.message = "Unable to load an xblock for usage_id {!r}".format(usage_id)
+        self.message = f"Unable to load an xblock for usage_id {usage_id!r}"
 
 
 class XBlockSaveError(Exception):
@@ -58,14 +58,14 @@ class InvalidScopeError(Exception):
     Raised to indicated that operating on the supplied scope isn't allowed by a KeyValueStore
     """
     def __init__(self, invalid_scope, valid_scopes=None):
-        super(InvalidScopeError, self).__init__()
+        super().__init__()
         if valid_scopes:
             self.message = "Invalid scope: {}. Valid scopes are: {}".format(
                 invalid_scope,
                 valid_scopes,
             )
         else:
-            self.message = "Invalid scope: {}".format(invalid_scope)
+            self.message = f"Invalid scope: {invalid_scope}"
 
 
 class NoSuchViewError(Exception):
@@ -81,7 +81,7 @@ class NoSuchViewError(Exception):
         """
         # Can't use super because Exception is an old-style class
         Exception.__init__(self)
-        self.message = "Unable to find view {!r} on block {!r}".format(view_name, block)
+        self.message = f"Unable to find view {view_name!r} on block {block!r}"
 
 
 class NoSuchHandlerError(Exception):
@@ -110,7 +110,7 @@ class JsonHandlerError(Exception):
     error response should be returned.
     """
     def __init__(self, status_code, message):
-        super(JsonHandlerError, self).__init__()
+        super().__init__()
         self.status_code = status_code
         self.message = message
 
@@ -136,3 +136,9 @@ class DisallowedFileError(Exception):
 
 class FieldDataDeprecationWarning(DeprecationWarning):
     """Warning for use of deprecated _field_data accessor"""
+
+
+class XBlockParseException(Exception):
+    """
+    Raised if parsing the XBlock olx fails.
+    """
