@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Tests the fundamentals of XBlocks including - but not limited to -
 metaclassing, field access, caching, serialization, and bulk saves.
@@ -9,10 +8,9 @@ from datetime import datetime
 import json
 import re
 import unittest
+from unittest.mock import patch, MagicMock, Mock
 
 import ddt
-import six
-from mock import patch, MagicMock, Mock
 import pytest
 from webob import Response
 
@@ -157,9 +155,9 @@ def test_set_field_access():
     field_tester = FieldTester(MagicMock(), DictFieldData({'field_a': [200], 'field_b': [11, 12, 13]}), Mock())
 
     # Check initial values have been set properly
-    assert set([200]) == field_tester.field_a
-    assert set([11, 12, 13]) == field_tester.field_b
-    assert set([4, 5, 6]) == field_tester.field_c
+    assert {200} == field_tester.field_a
+    assert {11, 12, 13} == field_tester.field_b
+    assert {4, 5, 6} == field_tester.field_c
     assert set() == field_tester.field_d
 
     # Update the fields
@@ -169,10 +167,10 @@ def test_set_field_access():
     field_tester.field_d.add(1)
 
     # The fields should be update in the cache, but /not/ in the underlying kvstore.
-    assert set([200, 1]) == field_tester.field_a
-    assert set([11, 12, 13, 14]) == field_tester.field_b
-    assert set([4, 6]) == field_tester.field_c
-    assert set([1]) == field_tester.field_d
+    assert {200, 1} == field_tester.field_a
+    assert {11, 12, 13, 14} == field_tester.field_b
+    assert {4, 6} == field_tester.field_c
+    assert {1} == field_tester.field_d
 
     # Examine model data directly
     #  Caveat: there's not a clean way to copy the originally provided values for `field_a` and `field_b`
@@ -186,16 +184,16 @@ def test_set_field_access():
     field_tester.save()
 
     # verify that the fields have been updated correctly
-    assert set([200, 1]) == field_tester.field_a
-    assert set([11, 12, 13, 14]) == field_tester.field_b
-    assert set([4, 6]) == field_tester.field_c
-    assert set([1]) == field_tester.field_d
+    assert {200, 1} == field_tester.field_a
+    assert {11, 12, 13, 14} == field_tester.field_b
+    assert {4, 6} == field_tester.field_c
+    assert {1} == field_tester.field_d
     # Now, the fields should be updated in the underlying kvstore
 
-    assert set([200, 1]) == field_tester._field_data.get(field_tester, 'field_a')
-    assert set([11, 12, 13, 14]) == field_tester._field_data.get(field_tester, 'field_b')
-    assert set([4, 6]) == field_tester._field_data.get(field_tester, 'field_c')
-    assert set([1]) == field_tester._field_data.get(field_tester, 'field_d')
+    assert {200, 1} == field_tester._field_data.get(field_tester, 'field_a')
+    assert {11, 12, 13, 14} == field_tester._field_data.get(field_tester, 'field_b')
+    assert {4, 6} == field_tester._field_data.get(field_tester, 'field_c')
+    assert {1} == field_tester._field_data.get(field_tester, 'field_d')
 
 
 def test_mutable_none_values():
@@ -417,7 +415,7 @@ def test_object_identity():
     # each time it's actually queried, so that the caching is
     # doing the work to maintain object identity.
     field_data = MagicMock(spec=FieldData)
-    field_data.get = lambda block, name, default=None: [name]  # pylint: disable=C0322
+    field_data.get = lambda block, name, default=None: [name]
     field_data.default = mock_default
     field_tester = FieldTester(
         runtime=TestRuntime(services={'field-data': field_data}),
@@ -447,7 +445,7 @@ def test_caching_is_per_instance():
         field_a = List(scope=Scope.settings)
 
     field_data = MagicMock(spec=FieldData)
-    field_data.get = lambda block, name, default=None: [name]  # pylint: disable=C0322
+    field_data.get = lambda block, name, default=None: [name]
 
     # Same field_data used in different objects should result
     # in separately-cached values, so that changing a value
@@ -503,26 +501,26 @@ def test_field_serialization():
 
 def test_class_tags():
     xblock = XBlock(None, None, None)
-    assert xblock._class_tags == set()  # pylint: disable=comparison-with-callable
+    assert xblock._class_tags == set()  # pylint: disable=comparison-with-callable, bad-option-value
 
     class Sub1Block(XBlock):
         """Toy XBlock"""
 
     sub1block = Sub1Block(None, None, None)
-    assert sub1block._class_tags == set()
+    assert sub1block._class_tags == set()  # pylint: disable=comparison-with-callable, bad-option-value
 
     @XBlock.tag("cat dog")
     class Sub2Block(Sub1Block):
         """Toy XBlock"""
 
     sub2block = Sub2Block(None, None, None)
-    assert sub2block._class_tags == set(["cat", "dog"])
+    assert sub2block._class_tags == {"cat", "dog"}  # pylint: disable=comparison-with-callable, bad-option-value
 
     class Sub3Block(Sub2Block):
         """Toy XBlock"""
 
     sub3block = Sub3Block(None, None, None)
-    assert sub3block._class_tags == set(["cat", "dog"])
+    assert sub3block._class_tags == {"cat", "dog"}  # pylint: disable=comparison-with-callable, bad-option-value
 
     @XBlock.tag("mixin")
     class MixinBlock(XBlock):
@@ -532,7 +530,9 @@ def test_class_tags():
         """Toy XBlock"""
 
     sub4block = Sub4Block(None, None, None)
-    assert sub4block._class_tags == set(["cat", "dog", "mixin"])
+    assert sub4block._class_tags == {  # pylint: disable=comparison-with-callable, bad-option-value
+        "cat", "dog", "mixin"
+    }
 
 
 def test_loading_tagged_classes():
@@ -558,7 +558,7 @@ def setup_save_failure(set_many):
     Set up tests for when there's a save error in the underlying KeyValueStore
     """
     field_data = MagicMock(spec=FieldData)
-    field_data.get = lambda block, name, default=None: 99  # pylint: disable=C0322
+    field_data.get = lambda block, name, default=None: 99
 
     field_data.set_many = set_many
 
@@ -746,7 +746,7 @@ def test_services_decorators():
     # A default XBlock has requested no services
     xblock = XBlock(None, None, None)
     assert XBlock._services_requested == {}
-    assert xblock._services_requested == {}  # pylint: disable=comparison-with-callable
+    assert xblock._services_requested == {}  # pylint: disable=comparison-with-callable, bad-option-value
 
     @XBlock.needs("n")
     @XBlock.wants("w")
@@ -754,8 +754,12 @@ def test_services_decorators():
         """XBlock using some services."""
 
     service_using_block = ServiceUsingBlock(None, scope_ids=None)
-    assert ServiceUsingBlock._services_requested == {'n': 'need', 'w': 'want'}
-    assert service_using_block._services_requested == {'n': 'need', 'w': 'want'}
+    assert ServiceUsingBlock._services_requested == {  # pylint: disable=comparison-with-callable, bad-option-value
+        'n': 'need', 'w': 'want'
+    }
+    assert service_using_block._services_requested == {  # pylint: disable=comparison-with-callable, bad-option-value
+        'n': 'need', 'w': 'want'
+    }
 
 
 def test_services_decorators_with_inheritance():
@@ -906,7 +910,7 @@ def test_json_handler_return_unicode():
 
     response = test_func(Mock(), test_request, "dummy_suffix")
     for request_part in response.request:  # pylint: disable=not-an-iterable
-        assert isinstance(request_part, six.text_type)
+        assert isinstance(request_part, str)
 
 
 @ddt.ddt
@@ -940,12 +944,12 @@ class OpenLocalResourceTest(unittest.TestCase):
             assert loadable.open_local_resource(uri.encode('utf-8')) == "!" + uri + "!"
 
     @ddt.data(
-        "public/hey.js".encode('utf-8'),
-        "public/sub/hey.js".encode('utf-8'),
-        "public/js/vendor/jNotify.jQuery.min.js".encode('utf-8'),
-        "public/something.foo".encode('utf-8'),         # Unknown file extension is fine
-        "public/a/long/PATH/no-problem=here$123.ext".encode('utf-8'),
-        "public/\N{SNOWMAN}.js".encode('utf-8'),
+        b"public/hey.js",
+        b"public/sub/hey.js",
+        b"public/js/vendor/jNotify.jQuery.min.js",
+        b"public/something.foo",         # Unknown file extension is fine
+        b"public/a/long/PATH/no-problem=here$123.ext",
+        "public/\N{SNOWMAN}.js".encode(),
     )
     def test_open_good_local_resource_binary(self, uri):
         loadable = self.LoadableXBlock(None, scope_ids=None)
@@ -969,13 +973,13 @@ class OpenLocalResourceTest(unittest.TestCase):
                 loadable.open_local_resource(uri)
 
     @ddt.data(
-        "public/../secret.js".encode('utf-8'),
-        "public/.git/secret.js".encode('utf-8'),
-        "static/secret.js".encode('utf-8'),
-        "../public/no-no.bad".encode('utf-8'),
-        "image.png".encode('utf-8'),
-        ".git/secret.js".encode('utf-8'),
-        "static/\N{SNOWMAN}.js".encode('utf-8'),
+        b"public/../secret.js",
+        b"public/.git/secret.js",
+        b"static/secret.js",
+        b"../public/no-no.bad",
+        b"image.png",
+        b".git/secret.js",
+        "static/\N{SNOWMAN}.js".encode(),
     )
     def test_open_bad_local_resource_binary(self, uri):
         loadable = self.LoadableXBlock(None, scope_ids=None)
